@@ -39,7 +39,6 @@ class Pod(NamespacedResource):
         priority_class_name: str | None = None,
         readiness_gates: list[Any] | None = None,
         resource_claims: list[Any] | None = None,
-        resources: dict[str, Any] | None = None,
         restart_policy: str | None = None,
         runtime_class_name: str | None = None,
         scheduler_name: str | None = None,
@@ -104,7 +103,8 @@ class Pod(NamespacedResource):
               ephemeralcontainers subresource.
 
             host_aliases (list[Any]): HostAliases is an optional list of hosts and IPs that will be injected
-              into the pod's hosts file if specified.
+              into the pod's hosts file if specified. This is only valid for
+              non-hostNetwork pods.
 
             host_ipc (bool): Use the host's ipc namespace. Optional: Default to false.
 
@@ -151,14 +151,9 @@ class Pod(NamespacedResource):
               https://kubernetes.io/docs/concepts/workloads/pods/init-
               containers/
 
-            node_name (str): NodeName indicates in which node this pod is scheduled. If empty, this
-              pod is a candidate for scheduling by the scheduler defined in
-              schedulerName. Once this field is set, the kubelet for this node
-              becomes responsible for the lifecycle of this pod. This field
-              should not be used to express a desire for the pod to be scheduled
-              on a specific node.
-              https://kubernetes.io/docs/concepts/scheduling-eviction/assign-
-              pod-node/#nodename
+            node_name (str): NodeName is a request to schedule this pod onto a specific node. If it
+              is non-empty, the scheduler simply schedules this pod onto that
+              node, assuming that it fits resource requirements.
 
             node_selector (dict[str, Any]): NodeSelector is a selector which must be true for the pod to fit on a
               node. Selector which must match a node's labels for the pod to be
@@ -211,8 +206,6 @@ class Pod(NamespacedResource):
               This is an alpha field and requires enabling the
               DynamicResourceAllocation feature gate.  This field is immutable.
 
-            resources (dict[str, Any]): ResourceRequirements describes the compute resource requirements.
-
             restart_policy (str): Restart policy for all containers within the pod. One of Always,
               OnFailure, Never. In some contexts, only a subset of those values
               may be permitted. Default to Always. More info:
@@ -235,7 +228,8 @@ class Pod(NamespacedResource):
               block scheduling the pod. If schedulingGates is not empty, the pod
               will stay in the SchedulingGated state and the scheduler will not
               attempt to schedule the pod.  SchedulingGates can only be set at
-              pod creation time, and be removed only afterwards.
+              pod creation time, and be removed only afterwards.  This is a beta
+              feature enabled by the PodSchedulingReadiness feature gate.
 
             security_context (dict[str, Any]): PodSecurityContext holds pod-level security attributes and common
               container settings. Some fields are also present in
@@ -243,8 +237,8 @@ class Pod(NamespacedResource):
               container.securityContext take precedence over field values of
               PodSecurityContext.
 
-            service_account (str): DeprecatedServiceAccount is a deprecated alias for ServiceAccountName.
-              Deprecated: Use serviceAccountName instead.
+            service_account (str): DeprecatedServiceAccount is a depreciated alias for
+              ServiceAccountName. Deprecated: Use serviceAccountName instead.
 
             service_account_name (str): ServiceAccountName is the name of the ServiceAccount to use to run
               this pod. More info: https://kubernetes.io/docs/tasks/configure-
@@ -255,8 +249,8 @@ class Pod(NamespacedResource):
               means setting the FQDN in the hostname field of the kernel (the
               nodename field of struct utsname). In Windows containers, this
               means setting the registry value of hostname for the registry key
-              HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\Tcpip\\Pa
-              rameters to FQDN. If a pod does not have FQDN, this has no effect.
+              HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Tcpip\Paramet
+              ers to FQDN. If a pod does not have FQDN, this has no effect.
               Default to false.
 
             share_process_namespace (bool): Share a single process namespace between all of the containers in a
@@ -319,7 +313,6 @@ class Pod(NamespacedResource):
         self.priority_class_name = priority_class_name
         self.readiness_gates = readiness_gates
         self.resource_claims = resource_claims
-        self.resources = resources
         self.restart_policy = restart_policy
         self.runtime_class_name = runtime_class_name
         self.scheduler_name = scheduler_name
@@ -419,9 +412,6 @@ class Pod(NamespacedResource):
             if self.resource_claims is not None:
                 _spec["resourceClaims"] = self.resource_claims
 
-            if self.resources is not None:
-                _spec["resources"] = self.resources
-
             if self.restart_policy is not None:
                 _spec["restartPolicy"] = self.restart_policy
 
